'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = fetch;

var _axios = require('axios');

var _axios2 = _interopRequireDefault(_axios);

var _qs = require('qs');

var _qs2 = _interopRequireDefault(_qs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function getROXFromPackage(pkg) {
  try {
    const ROX = require(`${pkg}/package.json`);
    return ROX;
  } catch (e) {
    return null;
  }
}

function getROX() {
  let ROX;
  ROX = getROXFromPackage('rox-browser');
  if (ROX) return ROX;
  ROX = getROXFromPackage('rox-ssr');
  if (ROX) return ROX;
  ROX = getROXFromPackage('rox-react-native');
  if (ROX) return ROX;
  ROX = getROXFromPackage('rox-node');
  if (ROX) return ROX;
  throw new Error('could not find ROX package');
}

const ROX = getROX();

const ENV = process.env.ROLLOUT_MODE;
const ENDPOINT = host => `https://${host}/device/embedded_configuration`;

function fetch(app_key, platform) {
  const url = getURL(getHost(ENV), {
    app_key,
    sdk_version: ROX.version,
    api_version: ROX.ROX.api_version,
    platform
  });
  return _axios2.default.get(url).then(({ data, status }) => {
    if (status === 200 && data && data.constructor === Object) {
      return data;
    }
    return Promise.reject();
  });
}

function getURL(host, properties) {
  return ENDPOINT(host) + _qs2.default.stringify(properties, { addQueryPrefix: true });
}

function getHost(environment) {
  switch (environment) {
    case 'local':
    case 'dev':
    case 'development':
      return 'localhost.rollout.io:9000';
      break;
    case 'qa':
      return 'qax.rollout.io';
      break;
  }
  return 'x-api.rollout.io';
}
module.exports = exports.default;